## Voltage Monitor with a Timestamp

### Example Summary

This [example code](https://dev.ti.com/tirex/explore/node?node=APdGY.QaC1AF1QFOGFJs6g__IOGqZri__LATEST) increments the RTC timestamp and toggles a GPIO (LED) every 1 second. It also sets up the ADC window comparator to monitor an analog input continuously while in LPM0. When the input voltage exceeds the high or low thresholds, the current RTC timestamp is captured, saved to FRAM and sent over UART to the host. 

There are several UART commands that read/write the RTC timestamp, read/write the threshold values and read the threshold timestamps (also sent automatically when triggered). These commands can be sent to the MSP430 using a terminal or they can be managed through the GUI Composer application using buttons, text boxes and sliders. Also, the [example code](https://dev.ti.com/tirex/explore/node?node=APdGY.QaC1AF1QFOGFJs6g__IOGqZri__LATEST) includes some logic to help prevent incorrect threshold values from getting applied.

The GUI example is available at [Voltage Monitor with a Timestamp](https://dev.ti.com/gallery/info/TIMSPGC/Voltage_Monitor_with_Timestamp/). The GUI example project is also included as a ZIP file and can be imported into [GUI Composer](https://dev.ti.com/gc/).

### Peripherals and Pin Assignments

* P1.0 --> GPIO (LED1)
* P1.1 <-- A1 ADC Input
* P1.4 --> eUSCI_A0 UART TX
* P1.5 <-- eUSCI_A0 UART RX
* P2.0 --> XOUT (optional for XT1)
* P2.1 <-- XIN (optional for XT1)

All other pins are initialized as output low to reduce power consumption.

### Clock Configuration

* ACLK = REFO ~32768Hz (default)
* SMCLK = DCO + FLL + 32-KHz REFO reference = 16-MHz
* MCLK = DCO + FLL + 32-KHz REFO reference = 16-MHz

XT1 can be used as an alternative to REFO if the crystal selector resistors are changed, and XT1 is enabled in the code.

### BoosterPacks, Board Resources and Jumper Settings

This example was developed and tested on the MSP-EXP430FR2433 LaunchPad.

* Pin J2.19: P1.1/A1, Connects to analog input driven externally
* Jumper J10: ON, Enables LED1 driven by P1.0
* Jumper J11: OFF, Disconnects P1.1 from LED2
* Jumper J101-GND: ON, Connects GND between the on-board debugger and LaunchPad 
* Jumper J101-3V3: ON, Powers the LaunchPad through USB
* Jumper J101-RXD: ON, Enables back-channel UART communication
* Jumper J101-TXD: ON, Enables back-channel UART communication

### Example Usage

* Connect the LaunchPad to your PC using the USB cable.
* Connect an analog signal to J2.19 (P1.1/A1) on the LaunchPad.
* Identify the COM port for the MSP Application UART interface (found under "Ports" in Device Manager for Windows).
* If using the non-GUI project:
	* Open a serial terminal (Docklight, Tera Term, etc.) with the following settings:
		```
		    COM Port:       COM# for MSP Application UART
		    Baud Rate:      9600
		    Data Bits:      8
		    Stop Bits:      1
		    Parity:         None
		    Flow Control:   None
		```
* If using the GUI project:
	* Import the GUI into [GUI Composer](https://dev.ti.com/gc/) and execute it.
	* Under "Options" > "Serial Port", update the GUI Serial Port settings:
		```
		    Ports:          COM# for MSP Application UART
		    Baud Rates:     9600
		```
	* Make sure the status at the bottom-left of the GUI shows "Hardware Connected".
	* Reset the device to initialize everything by pressing and releasing switch S3 on the LaunchPad.

* Then, continue with the example: 
	* RTC
		* Read the RTC timestamp. For example, it should be something like 0x0000000E if 14 seconds have elapsed after the device was reset.
		* Set the RTC timestamp according to the current time in POSIX format.
		* Double-check the RTC timestamp has been updated by reading it again.
		* If using the non-GUI project, the timestamp data is transmitted in hexadecimal format.
		* If using the GUI project, the timestamp data is transmitted in a GUI Composer packet and will be displayed as a hexadecimal value in the GUI. The value is shown in a text box which can also be modified to set the RTC timestamp.
	* ADC window comparator thresholds
		* The internal 1.5V reference voltage (VREF) is used.		
		* There are two thresholds enabled in this example: high and low thresholds.
			* The default high threshold is set to 818 (0x332) which is 818/1023 = ~80.0% of the ADC reference voltage.
			* The default low threshold is set to 682 (0x2AA) which is 682/1023 = ~66.7% of the ADC reference voltage.
		* These thresholds can be changed by writing new threshold values over UART.
			* If the new threshold values overlap, the new values are ignored.
			* If the high threshold value exceeds the maximum allowable value (1023), then the max value is applied as the new high threshold.
		* If using the non-GUI project, the threshold data is transmitted in hexadecimal format.
		* If using the GUI project, the threshold data is transmitted in a GUI Composer packet and will be displayed as a decimal value in the GUI. The values can be changed by entering them in text boxes or adjusting sliders.
	* Threshold timestamps
		* If the ADC input is between the low and high thresholds, the device stays in low power mode while continuing to monitor the input.
		* If the ADC input is higher than the high threshold or lower than the low threshold, the device will store the timestamp of each event in FRAM and start sending those timestamps over UART.
		* If using the non-GUI project, the timestamp data is transmitted in hexadecimal format.
		* If using the GUI project, the timestamp data is transmitted in a GUI Composer packet and will be displayed as a hexadecimal value in a text box in the GUI.